@@ -8,7 +8,7 @@
    Author: Paul Hardy, unifoundry <at> unifoundry.com, December 2007
    
    
-   Copyright (C) 2007, 2008, 2013, 2017 Paul Hardy
+   Copyright (C) 2007, 2008, 2013, 2017, 2019, 2022 Paul Hardy
 
    LICENSE:
 
@@ -84,6 +84,15 @@
         or bottom to top.
       - Add DEBUG compile flag to print header information, to ease
         adding support for additional bitmap formats in the future.
+
+   13 March 2022 [Paul Hardy]:
+      - Added support for 24 bits per pixel RGB file.
+
+   12 June 2022 [Paul Hardy]:
+      - Set U+11B00..U+11B5F (Devanagari Extended-A) to be wide.
+      - Set U+11F00..U+11F5F (Kawi) to be wide.
+
+
 */
 
 #include <stdio.h>
@@ -288,6 +297,8 @@ main (int argc, char *argv[])
    for (i = 0x0119A0; i <= 0x0119FF; i++) wide[i] = 1; /* Nandinagari        */
    for (i = 0x011A00; i <= 0x011A4F; i++) wide[i] = 1; /* Zanabazar Square   */
    for (i = 0x011A50; i <= 0x011AAF; i++) wide[i] = 1; /* Soyombo            */
+   for (i = 0x011B00; i <= 0x011B5F; i++) wide[i] = 1; /* Devanagari Extended-A*/
+   for (i = 0x011F00; i <= 0x011F5F; i++) wide[i] = 1; /* Kawi               */
    for (i = 0x011C00; i <= 0x011C6F; i++) wide[i] = 1; /* Bhaiksuki          */
    for (i = 0x011C70; i <= 0x011CBF; i++) wide[i] = 1; /* Marchen            */
    for (i = 0x011D00; i <= 0x011D5F; i++) wide[i] = 1; /* Masaram Gondi      */
@@ -481,14 +492,17 @@ main (int argc, char *argv[])
                next_pixels = fgetc (infp);
             }
             /* Read a 32 bit per pixel RGB image; convert to monochrome */
-            else if (bmp_header.bits_per_pixel == 32) {
+            else if ( bmp_header.bits_per_pixel == 24 ||
+                      bmp_header.bits_per_pixel == 32) {
                next_pixels = 0;
                for (k = 0; k < 8; k++) {  /* get next 8 pixels */
                   this_pixel = (fgetc (infp) & 0xFF) +
                                (fgetc (infp) & 0xFF) +
                                (fgetc (infp) & 0xFF);
 
-                  (void) fgetc (infp);  /* ignore alpha value */
+                  if (bmp_header.bits_per_pixel == 32) {
+                     (void) fgetc (infp);  /* ignore alpha value */
+                  }
 
                   /* convert RGB color space to monochrome */
                   if (this_pixel >= (128 * 3))
